/* Form definition file generated with fdesign. */

#include "forms.h"
#include <stdlib.h>
#include "xgod.h"

FD_main *create_form_main(void)
{
  FL_OBJECT *obj;
  FD_main *fdui = (FD_main *) fl_calloc(1, sizeof(*fdui));

  fdui->main = fl_bgn_form(FL_NO_BOX, 330, 250);
  obj = fl_add_box(FL_UP_BOX,0,0,330,250,"");
  fdui->xpm1 = obj = fl_add_pixmap(FL_NORMAL_PIXMAP,30,70,200,160,"");
    fl_set_object_boxtype(obj,FL_DOWN_BOX);
  obj = fl_add_text(FL_NORMAL_TEXT,30,20,280,40,"Xgod");
    fl_set_object_boxtype(obj,FL_EMBOSSED_BOX);
    fl_set_object_lsize(obj,FL_LARGE_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_CENTER|FL_ALIGN_INSIDE);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE+FL_EMBOSSED_STYLE);
  fdui->bf = obj = fl_add_button(FL_NORMAL_BUTTON,250,70,60,40,"File");
    fl_set_object_callback(obj,start,0);
  fdui->bi = obj = fl_add_button(FL_NORMAL_BUTTON,250,130,60,40,"Info");
    fl_set_object_callback(obj,open_info,0);
  fdui->bq = obj = fl_add_button(FL_NORMAL_BUTTON,250,190,60,40,"Quit");
  fl_end_form();

  fdui->main->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

FD_file *create_form_file(void)
{
  FL_OBJECT *obj;
  FD_file *fdui = (FD_file *) fl_calloc(1, sizeof(*fdui));

  fdui->file = fl_bgn_form(FL_NO_BOX, 300, 100);
  obj = fl_add_box(FL_UP_BOX,0,0,300,100,"");
  fdui->in = obj = fl_add_input(FL_NORMAL_INPUT,50,20,140,20,"File: ");
  fdui->bb = obj = fl_add_button(FL_NORMAL_BUTTON,210,20,70,20,"Browse");
    fl_set_object_callback(obj,fselect,0);
  fdui->bn = obj = fl_add_button(FL_NORMAL_BUTTON,20,60,120,20,"Open");
    fl_set_object_callback(obj,open_choice,0);
  fdui->bc = obj = fl_add_button(FL_NORMAL_BUTTON,160,60,120,20,"Cancel");
    fl_set_object_callback(obj,close_file,0);
  fl_end_form();

  fdui->file->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

FD_choice *create_form_choice(void)
{
  FL_OBJECT *obj;
  FD_choice *fdui = (FD_choice *) fl_calloc(1, sizeof(*fdui));

  fdui->choice = fl_bgn_form(FL_NO_BOX, 340, 320);
  obj = fl_add_box(FL_UP_BOX,0,0,340,320,"");

  fdui->size = fl_bgn_group();
  fdui->f1 = obj = fl_add_labelframe(FL_ENGRAVED_FRAME,20,20,70,80,"Size");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
  fdui->b1 = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,30,60,20,"Small");
  fdui->b2 = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,50,60,20,"Medium");
  fdui->b3 = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,70,60,20,"Large");
  fl_end_group();


  fdui->align = fl_bgn_group();
  fdui->f3 = obj = fl_add_labelframe(FL_ENGRAVED_FRAME,20,120,70,80," Align ");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
  fdui->b4 = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,130,60,20,"Left");
  fdui->b5 = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,150,60,20,"Center");
  fdui->b6 = obj = fl_add_checkbutton(FL_RADIO_BUTTON,20,170,60,20,"Right");
  fl_end_group();


  fdui->shape = fl_bgn_group();
  fdui->f2 = obj = fl_add_labelframe(FL_ENGRAVED_FRAME,100,20,220,220,"Shape");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
  fdui->bb[5] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,180,100,60,60,"");
    fl_set_object_callback(obj,shape,5);
  fdui->bb[1] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,110,30,60,60,"");
    fl_set_object_callback(obj,shape,1);
  fdui->bb[3] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,250,30,60,60,"");
    fl_set_object_callback(obj,shape,3);
  fdui->bb[9] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,250,170,60,60,"");
    fl_set_object_callback(obj,shape,9);
  fdui->bb[2] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,180,30,60,40,"");
    fl_set_object_callback(obj,shape,2);
  fdui->bb[7] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,110,170,60,60,"");
    fl_set_object_callback(obj,shape,7);
  fdui->bb[4] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,110,100,40,60,"");
    fl_set_object_callback(obj,shape,4);
  fdui->bb[6] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,270,100,40,60,"");
    fl_set_object_callback(obj,shape,6);
  fdui->bb[8] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,180,190,60,40,"");
    fl_set_object_callback(obj,shape,8);
  fl_end_group();

  fdui->bok = obj = fl_add_button(FL_NORMAL_BUTTON,20,210,70,40,"Ok");
    fl_set_object_callback(obj,open_dia,0);
  fdui->bc = obj = fl_add_button(FL_NORMAL_BUTTON,20,260,70,40,"Cancel");
    fl_set_object_callback(obj,close_choice,0);
  fdui->cy = obj = fl_add_counter(FL_SIMPLE_COUNTER,120,280,200,20,"y:");
    fl_set_object_lalign(obj,FL_ALIGN_LEFT);
    fl_set_counter_precision(obj, 0);
    fl_set_counter_bounds(obj, 0, 19);
    fl_set_counter_step(obj, 1, 1);
  fdui->cx = obj = fl_add_counter(FL_SIMPLE_COUNTER,120,250,200,20,"x:");
    fl_set_object_lalign(obj,FL_ALIGN_LEFT);
    fl_set_counter_precision(obj, 0);
    fl_set_counter_bounds(obj, 0, 19);
    fl_set_counter_step(obj, 1, 1);
  fl_end_form();

  fdui->choice->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

FD_dia *create_form_dia(void)
{
  FL_OBJECT *obj;
  FD_dia *fdui = (FD_dia *) fl_calloc(1, sizeof(*fdui));

  fdui->dia = fl_bgn_form(FL_NO_BOX, 500, 430);
  obj = fl_add_box(FL_UP_BOX,0,0,500,430,"");
  obj = fl_add_frame(FL_ENGRAVED_FRAME,15,15,390,390,"");
  fdui->b[1][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[1][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,20,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[2][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,40,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[3][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,60,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[4][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,80,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[5][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,100,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[6][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,120,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[7][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,140,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[8][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,160,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[9][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,180,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[10][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,200,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[11][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,220,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[12][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,240,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[13][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,260,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[14][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,280,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[15][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,300,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[16][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,320,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[17][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,340,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[18][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,360,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][1] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,20,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][2] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,40,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][3] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,60,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][4] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,80,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][5] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,100,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][6] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,120,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][7] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,140,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][8] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,160,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][9] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,180,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][10] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,200,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][11] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,220,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][12] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,240,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][13] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,260,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][14] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,280,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][15] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,300,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][16] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,320,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][17] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,340,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][18] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,360,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->b[19][19] = obj = fl_add_bitmap(FL_NORMAL_BITMAP,380,380,20,20,"");
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  fdui->p[1][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,20,20,20,"");
    fl_set_object_callback(obj,stone,1);
  fdui->p[1][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,40,20,20,"");
    fl_set_object_callback(obj,stone,21);
  fdui->p[1][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,60,20,20,"");
    fl_set_object_callback(obj,stone,41);
  fdui->p[1][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,80,20,20,"");
    fl_set_object_callback(obj,stone,61);
  fdui->p[1][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,100,20,20,"");
    fl_set_object_callback(obj,stone,81);
  fdui->p[1][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,120,20,20,"");
    fl_set_object_callback(obj,stone,101);
  fdui->p[1][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,140,20,20,"");
    fl_set_object_callback(obj,stone,121);
  fdui->p[1][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,160,20,20,"");
    fl_set_object_callback(obj,stone,141);
  fdui->p[1][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,180,20,20,"");
    fl_set_object_callback(obj,stone,161);
  fdui->p[1][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,200,20,20,"");
    fl_set_object_callback(obj,stone,181);
  fdui->p[1][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,220,20,20,"");
    fl_set_object_callback(obj,stone,201);
  fdui->p[1][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,240,20,20,"");
    fl_set_object_callback(obj,stone,221);
  fdui->p[1][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,260,20,20,"");
    fl_set_object_callback(obj,stone,241);
  fdui->p[1][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,280,20,20,"");
    fl_set_object_callback(obj,stone,261);
  fdui->p[1][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,300,20,20,"");
    fl_set_object_callback(obj,stone,281);
  fdui->p[1][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,320,20,20,"");
    fl_set_object_callback(obj,stone,301);
  fdui->p[1][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,340,20,20,"");
    fl_set_object_callback(obj,stone,321);
  fdui->p[1][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,360,20,20,"");
    fl_set_object_callback(obj,stone,341);
  fdui->p[1][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,20,380,20,20,"");
    fl_set_object_callback(obj,stone,361);
  fdui->p[2][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,20,20,20,"");
    fl_set_object_callback(obj,stone,2);
  fdui->p[2][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,40,20,20,"");
    fl_set_object_callback(obj,stone,22);
  fdui->p[2][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,60,20,20,"");
    fl_set_object_callback(obj,stone,42);
  fdui->p[2][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,80,20,20,"");
    fl_set_object_callback(obj,stone,62);
  fdui->p[2][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,100,20,20,"");
    fl_set_object_callback(obj,stone,82);
  fdui->p[2][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,120,20,20,"");
    fl_set_object_callback(obj,stone,102);
  fdui->p[2][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,140,20,20,"");
    fl_set_object_callback(obj,stone,122);
  fdui->p[2][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,160,20,20,"");
    fl_set_object_callback(obj,stone,142);
  fdui->p[2][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,180,20,20,"");
    fl_set_object_callback(obj,stone,162);
  fdui->p[2][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,200,20,20,"");
    fl_set_object_callback(obj,stone,182);
  fdui->p[2][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,220,20,20,"");
    fl_set_object_callback(obj,stone,202);
  fdui->p[2][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,240,20,20,"");
    fl_set_object_callback(obj,stone,222);
  fdui->p[2][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,260,20,20,"");
    fl_set_object_callback(obj,stone,242);
  fdui->p[2][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,280,20,20,"");
    fl_set_object_callback(obj,stone,262);
  fdui->p[2][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,300,20,20,"");
    fl_set_object_callback(obj,stone,282);
  fdui->p[2][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,320,20,20,"");
    fl_set_object_callback(obj,stone,302);
  fdui->p[2][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,340,20,20,"");
    fl_set_object_callback(obj,stone,322);
  fdui->p[2][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,360,20,20,"");
    fl_set_object_callback(obj,stone,342);
  fdui->p[2][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,40,380,20,20,"");
    fl_set_object_callback(obj,stone,362);
  fdui->p[3][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,20,20,20,"");
    fl_set_object_callback(obj,stone,3);
  fdui->p[3][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,40,20,20,"");
    fl_set_object_callback(obj,stone,23);
  fdui->p[3][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,60,20,20,"");
    fl_set_object_callback(obj,stone,43);
  fdui->p[3][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,80,20,20,"");
    fl_set_object_callback(obj,stone,63);
  fdui->p[3][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,100,20,20,"");
    fl_set_object_callback(obj,stone,83);
  fdui->p[3][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,120,20,20,"");
    fl_set_object_callback(obj,stone,103);
  fdui->p[3][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,140,20,20,"");
    fl_set_object_callback(obj,stone,123);
  fdui->p[3][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,160,20,20,"");
    fl_set_object_callback(obj,stone,143);
  fdui->p[3][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,180,20,20,"");
    fl_set_object_callback(obj,stone,163);
  fdui->p[3][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,200,20,20,"");
    fl_set_object_callback(obj,stone,183);
  fdui->p[3][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,220,20,20,"");
    fl_set_object_callback(obj,stone,203);
  fdui->p[3][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,240,20,20,"");
    fl_set_object_callback(obj,stone,223);
  fdui->p[3][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,260,20,20,"");
    fl_set_object_callback(obj,stone,243);
  fdui->p[3][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,280,20,20,"");
    fl_set_object_callback(obj,stone,263);
  fdui->p[3][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,300,20,20,"");
    fl_set_object_callback(obj,stone,283);
  fdui->p[3][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,320,20,20,"");
    fl_set_object_callback(obj,stone,303);
  fdui->p[3][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,340,20,20,"");
    fl_set_object_callback(obj,stone,323);
  fdui->p[3][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,360,20,20,"");
    fl_set_object_callback(obj,stone,343);
  fdui->p[3][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,60,380,20,20,"");
    fl_set_object_callback(obj,stone,363);
  fdui->p[4][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,20,20,20,"");
    fl_set_object_callback(obj,stone,4);
  fdui->p[4][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,40,20,20,"");
    fl_set_object_callback(obj,stone,24);
  fdui->p[4][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,60,20,20,"");
    fl_set_object_callback(obj,stone,44);
  fdui->p[4][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,80,20,20,"");
    fl_set_object_callback(obj,stone,64);
  fdui->p[4][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,100,20,20,"");
    fl_set_object_callback(obj,stone,84);
  fdui->p[4][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,120,20,20,"");
    fl_set_object_callback(obj,stone,104);
  fdui->p[4][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,140,20,20,"");
    fl_set_object_callback(obj,stone,124);
  fdui->p[4][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,160,20,20,"");
    fl_set_object_callback(obj,stone,144);
  fdui->p[4][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,180,20,20,"");
    fl_set_object_callback(obj,stone,164);
  fdui->p[4][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,200,20,20,"");
    fl_set_object_callback(obj,stone,184);
  fdui->p[4][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,220,20,20,"");
    fl_set_object_callback(obj,stone,204);
  fdui->p[4][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,240,20,20,"");
    fl_set_object_callback(obj,stone,224);
  fdui->p[4][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,260,20,20,"");
    fl_set_object_callback(obj,stone,244);
  fdui->p[4][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,280,20,20,"");
    fl_set_object_callback(obj,stone,264);
  fdui->p[4][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,300,20,20,"");
    fl_set_object_callback(obj,stone,284);
  fdui->p[4][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,320,20,20,"");
    fl_set_object_callback(obj,stone,304);
  fdui->p[4][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,340,20,20,"");
    fl_set_object_callback(obj,stone,324);
  fdui->p[4][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,360,20,20,"");
    fl_set_object_callback(obj,stone,344);
  fdui->p[4][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,80,380,20,20,"");
    fl_set_object_callback(obj,stone,364);
  fdui->p[5][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,20,20,20,"");
    fl_set_object_callback(obj,stone,5);
  fdui->p[5][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,40,20,20,"");
    fl_set_object_callback(obj,stone,25);
  fdui->p[5][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,60,20,20,"");
    fl_set_object_callback(obj,stone,45);
  fdui->p[5][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,80,20,20,"");
    fl_set_object_callback(obj,stone,65);
  fdui->p[5][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,100,20,20,"");
    fl_set_object_callback(obj,stone,85);
  fdui->p[5][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,120,20,20,"");
    fl_set_object_callback(obj,stone,105);
  fdui->p[5][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,140,20,20,"");
    fl_set_object_callback(obj,stone,125);
  fdui->p[5][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,160,20,20,"");
    fl_set_object_callback(obj,stone,145);
  fdui->p[5][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,180,20,20,"");
    fl_set_object_callback(obj,stone,165);
  fdui->p[5][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,200,20,20,"");
    fl_set_object_callback(obj,stone,185);
  fdui->p[5][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,220,20,20,"");
    fl_set_object_callback(obj,stone,205);
  fdui->p[5][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,240,20,20,"");
    fl_set_object_callback(obj,stone,225);
  fdui->p[5][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,260,20,20,"");
    fl_set_object_callback(obj,stone,245);
  fdui->p[5][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,280,20,20,"");
    fl_set_object_callback(obj,stone,265);
  fdui->p[5][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,300,20,20,"");
    fl_set_object_callback(obj,stone,285);
  fdui->p[5][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,320,20,20,"");
    fl_set_object_callback(obj,stone,305);
  fdui->p[5][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,340,20,20,"");
    fl_set_object_callback(obj,stone,325);
  fdui->p[5][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,360,20,20,"");
    fl_set_object_callback(obj,stone,345);
  fdui->p[5][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,100,380,20,20,"");
    fl_set_object_callback(obj,stone,365);
  fdui->p[6][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,20,20,20,"");
    fl_set_object_callback(obj,stone,6);
  fdui->p[6][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,40,20,20,"");
    fl_set_object_callback(obj,stone,26);
  fdui->p[6][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,60,20,20,"");
    fl_set_object_callback(obj,stone,46);
  fdui->p[6][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,80,20,20,"");
    fl_set_object_callback(obj,stone,66);
  fdui->p[6][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,100,20,20,"");
    fl_set_object_callback(obj,stone,86);
  fdui->p[6][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,120,20,20,"");
    fl_set_object_callback(obj,stone,106);
  fdui->p[6][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,140,20,20,"");
    fl_set_object_callback(obj,stone,126);
  fdui->p[6][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,160,20,20,"");
    fl_set_object_callback(obj,stone,146);
  fdui->p[6][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,180,20,20,"");
    fl_set_object_callback(obj,stone,166);
  fdui->p[6][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,200,20,20,"");
    fl_set_object_callback(obj,stone,186);
  fdui->p[6][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,220,20,20,"");
    fl_set_object_callback(obj,stone,206);
  fdui->p[6][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,240,20,20,"");
    fl_set_object_callback(obj,stone,226);
  fdui->p[6][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,260,20,20,"");
    fl_set_object_callback(obj,stone,246);
  fdui->p[6][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,280,20,20,"");
    fl_set_object_callback(obj,stone,266);
  fdui->p[6][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,300,20,20,"");
    fl_set_object_callback(obj,stone,286);
  fdui->p[6][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,320,20,20,"");
    fl_set_object_callback(obj,stone,306);
  fdui->p[6][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,340,20,20,"");
    fl_set_object_callback(obj,stone,326);
  fdui->p[6][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,360,20,20,"");
    fl_set_object_callback(obj,stone,346);
  fdui->p[6][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,120,380,20,20,"");
    fl_set_object_callback(obj,stone,366);
  fdui->p[7][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,20,20,20,"");
    fl_set_object_callback(obj,stone,7);
  fdui->p[7][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,40,20,20,"");
    fl_set_object_callback(obj,stone,27);
  fdui->p[7][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,60,20,20,"");
    fl_set_object_callback(obj,stone,47);
  fdui->p[7][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,80,20,20,"");
    fl_set_object_callback(obj,stone,67);
  fdui->p[7][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,100,20,20,"");
    fl_set_object_callback(obj,stone,87);
  fdui->p[7][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,120,20,20,"");
    fl_set_object_callback(obj,stone,107);
  fdui->p[7][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,140,20,20,"");
    fl_set_object_callback(obj,stone,127);
  fdui->p[7][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,160,20,20,"");
    fl_set_object_callback(obj,stone,147);
  fdui->p[7][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,180,20,20,"");
    fl_set_object_callback(obj,stone,167);
  fdui->p[7][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,200,20,20,"");
    fl_set_object_callback(obj,stone,187);
  fdui->p[7][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,220,20,20,"");
    fl_set_object_callback(obj,stone,207);
  fdui->p[7][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,240,20,20,"");
    fl_set_object_callback(obj,stone,227);
  fdui->p[7][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,260,20,20,"");
    fl_set_object_callback(obj,stone,247);
  fdui->p[7][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,280,20,20,"");
    fl_set_object_callback(obj,stone,267);
  fdui->p[7][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,300,20,20,"");
    fl_set_object_callback(obj,stone,287);
  fdui->p[7][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,320,20,20,"");
    fl_set_object_callback(obj,stone,307);
  fdui->p[7][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,340,20,20,"");
    fl_set_object_callback(obj,stone,327);
  fdui->p[7][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,360,20,20,"");
    fl_set_object_callback(obj,stone,347);
  fdui->p[7][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,140,380,20,20,"");
    fl_set_object_callback(obj,stone,367);
  fdui->p[8][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,20,20,20,"");
    fl_set_object_callback(obj,stone,8);
  fdui->p[8][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,40,20,20,"");
    fl_set_object_callback(obj,stone,28);
  fdui->p[8][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,60,20,20,"");
    fl_set_object_callback(obj,stone,48);
  fdui->p[8][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,80,20,20,"");
    fl_set_object_callback(obj,stone,68);
  fdui->p[8][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,100,20,20,"");
    fl_set_object_callback(obj,stone,88);
  fdui->p[8][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,120,20,20,"");
    fl_set_object_callback(obj,stone,108);
  fdui->p[8][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,140,20,20,"");
    fl_set_object_callback(obj,stone,128);
  fdui->p[8][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,160,20,20,"");
    fl_set_object_callback(obj,stone,148);
  fdui->p[8][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,180,20,20,"");
    fl_set_object_callback(obj,stone,168);
  fdui->p[8][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,200,20,20,"");
    fl_set_object_callback(obj,stone,188);
  fdui->p[8][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,220,20,20,"");
    fl_set_object_callback(obj,stone,208);
  fdui->p[8][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,240,20,20,"");
    fl_set_object_callback(obj,stone,228);
  fdui->p[8][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,260,20,20,"");
    fl_set_object_callback(obj,stone,248);
  fdui->p[8][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,280,20,20,"");
    fl_set_object_callback(obj,stone,268);
  fdui->p[8][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,300,20,20,"");
    fl_set_object_callback(obj,stone,288);
  fdui->p[8][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,320,20,20,"");
    fl_set_object_callback(obj,stone,308);
  fdui->p[8][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,340,20,20,"");
    fl_set_object_callback(obj,stone,328);
  fdui->p[8][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,360,20,20,"");
    fl_set_object_callback(obj,stone,348);
  fdui->p[8][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,160,380,20,20,"");
    fl_set_object_callback(obj,stone,368);
  fdui->p[9][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,20,20,20,"");
    fl_set_object_callback(obj,stone,9);
  fdui->p[9][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,40,20,20,"");
    fl_set_object_callback(obj,stone,29);
  fdui->p[9][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,60,20,20,"");
    fl_set_object_callback(obj,stone,49);
  fdui->p[9][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,80,20,20,"");
    fl_set_object_callback(obj,stone,69);
  fdui->p[9][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,100,20,20,"");
    fl_set_object_callback(obj,stone,89);
  fdui->p[9][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,120,20,20,"");
    fl_set_object_callback(obj,stone,109);
  fdui->p[9][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,140,20,20,"");
    fl_set_object_callback(obj,stone,129);
  fdui->p[9][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,160,20,20,"");
    fl_set_object_callback(obj,stone,149);
  fdui->p[9][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,180,20,20,"");
    fl_set_object_callback(obj,stone,169);
  fdui->p[9][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,200,20,20,"");
    fl_set_object_callback(obj,stone,189);
  fdui->p[9][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,220,20,20,"");
    fl_set_object_callback(obj,stone,209);
  fdui->p[9][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,240,20,20,"");
    fl_set_object_callback(obj,stone,229);
  fdui->p[9][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,260,20,20,"");
    fl_set_object_callback(obj,stone,249);
  fdui->p[9][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,280,20,20,"");
    fl_set_object_callback(obj,stone,269);
  fdui->p[9][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,300,20,20,"");
    fl_set_object_callback(obj,stone,289);
  fdui->p[9][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,320,20,20,"");
    fl_set_object_callback(obj,stone,309);
  fdui->p[9][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,340,20,20,"");
    fl_set_object_callback(obj,stone,329);
  fdui->p[9][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,360,20,20,"");
    fl_set_object_callback(obj,stone,349);
  fdui->p[9][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,180,380,20,20,"");
    fl_set_object_callback(obj,stone,369);
  fdui->p[10][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,20,20,20,"");
    fl_set_object_callback(obj,stone,10);
  fdui->p[10][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,40,20,20,"");
    fl_set_object_callback(obj,stone,30);
  fdui->p[10][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,60,20,20,"");
    fl_set_object_callback(obj,stone,50);
  fdui->p[10][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,80,20,20,"");
    fl_set_object_callback(obj,stone,70);
  fdui->p[10][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,100,20,20,"");
    fl_set_object_callback(obj,stone,90);
  fdui->p[10][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,120,20,20,"");
    fl_set_object_callback(obj,stone,110);
  fdui->p[10][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,140,20,20,"");
    fl_set_object_callback(obj,stone,130);
  fdui->p[10][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,160,20,20,"");
    fl_set_object_callback(obj,stone,150);
  fdui->p[10][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,180,20,20,"");
    fl_set_object_callback(obj,stone,170);
  fdui->p[10][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,200,20,20,"");
    fl_set_object_callback(obj,stone,190);
  fdui->p[10][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,220,20,20,"");
    fl_set_object_callback(obj,stone,210);
  fdui->p[10][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,240,20,20,"");
    fl_set_object_callback(obj,stone,230);
  fdui->p[10][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,260,20,20,"");
    fl_set_object_callback(obj,stone,250);
  fdui->p[10][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,280,20,20,"");
    fl_set_object_callback(obj,stone,270);
  fdui->p[10][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,300,20,20,"");
    fl_set_object_callback(obj,stone,290);
  fdui->p[10][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,320,20,20,"");
    fl_set_object_callback(obj,stone,310);
  fdui->p[10][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,340,20,20,"");
    fl_set_object_callback(obj,stone,330);
  fdui->p[10][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,360,20,20,"");
    fl_set_object_callback(obj,stone,350);
  fdui->p[10][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,200,380,20,20,"");
    fl_set_object_callback(obj,stone,370);
  fdui->p[11][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,20,20,20,"");
    fl_set_object_callback(obj,stone,11);
  fdui->p[11][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,40,20,20,"");
    fl_set_object_callback(obj,stone,31);
  fdui->p[11][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,60,20,20,"");
    fl_set_object_callback(obj,stone,51);
  fdui->p[11][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,80,20,20,"");
    fl_set_object_callback(obj,stone,71);
  fdui->p[11][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,100,20,20,"");
    fl_set_object_callback(obj,stone,91);
  fdui->p[11][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,120,20,20,"");
    fl_set_object_callback(obj,stone,111);
  fdui->p[11][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,140,20,20,"");
    fl_set_object_callback(obj,stone,131);
  fdui->p[11][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,160,20,20,"");
    fl_set_object_callback(obj,stone,151);
  fdui->p[11][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,180,20,20,"");
    fl_set_object_callback(obj,stone,171);
  fdui->p[11][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,200,20,20,"");
    fl_set_object_callback(obj,stone,191);
  fdui->p[11][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,220,20,20,"");
    fl_set_object_callback(obj,stone,211);
  fdui->p[11][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,240,20,20,"");
    fl_set_object_callback(obj,stone,231);
  fdui->p[11][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,260,20,20,"");
    fl_set_object_callback(obj,stone,251);
  fdui->p[11][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,280,20,20,"");
    fl_set_object_callback(obj,stone,271);
  fdui->p[11][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,300,20,20,"");
    fl_set_object_callback(obj,stone,291);
  fdui->p[11][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,320,20,20,"");
    fl_set_object_callback(obj,stone,311);
  fdui->p[11][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,340,20,20,"");
    fl_set_object_callback(obj,stone,331);
  fdui->p[11][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,360,20,20,"");
    fl_set_object_callback(obj,stone,351);
  fdui->p[11][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,220,380,20,20,"");
    fl_set_object_callback(obj,stone,371);
  fdui->p[12][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,20,20,20,"");
    fl_set_object_callback(obj,stone,12);
  fdui->p[12][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,40,20,20,"");
    fl_set_object_callback(obj,stone,32);
  fdui->p[12][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,60,20,20,"");
    fl_set_object_callback(obj,stone,52);
  fdui->p[12][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,80,20,20,"");
    fl_set_object_callback(obj,stone,72);
  fdui->p[12][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,100,20,20,"");
    fl_set_object_callback(obj,stone,92);
  fdui->p[12][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,120,20,20,"");
    fl_set_object_callback(obj,stone,112);
  fdui->p[12][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,140,20,20,"");
    fl_set_object_callback(obj,stone,132);
  fdui->p[12][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,160,20,20,"");
    fl_set_object_callback(obj,stone,152);
  fdui->p[12][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,180,20,20,"");
    fl_set_object_callback(obj,stone,172);
  fdui->p[12][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,200,20,20,"");
    fl_set_object_callback(obj,stone,192);
  fdui->p[12][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,220,20,20,"");
    fl_set_object_callback(obj,stone,212);
  fdui->p[12][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,240,20,20,"");
    fl_set_object_callback(obj,stone,232);
  fdui->p[12][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,260,20,20,"");
    fl_set_object_callback(obj,stone,252);
  fdui->p[12][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,280,20,20,"");
    fl_set_object_callback(obj,stone,272);
  fdui->p[12][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,300,20,20,"");
    fl_set_object_callback(obj,stone,292);
  fdui->p[12][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,320,20,20,"");
    fl_set_object_callback(obj,stone,312);
  fdui->p[12][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,340,20,20,"");
    fl_set_object_callback(obj,stone,332);
  fdui->p[12][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,360,20,20,"");
    fl_set_object_callback(obj,stone,352);
  fdui->p[12][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,240,380,20,20,"");
    fl_set_object_callback(obj,stone,372);
  fdui->p[13][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,20,20,20,"");
    fl_set_object_callback(obj,stone,13);
  fdui->p[13][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,40,20,20,"");
    fl_set_object_callback(obj,stone,33);
  fdui->p[13][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,60,20,20,"");
    fl_set_object_callback(obj,stone,53);
  fdui->p[13][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,80,20,20,"");
    fl_set_object_callback(obj,stone,73);
  fdui->p[13][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,100,20,20,"");
    fl_set_object_callback(obj,stone,93);
  fdui->p[13][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,120,20,20,"");
    fl_set_object_callback(obj,stone,113);
  fdui->p[13][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,140,20,20,"");
    fl_set_object_callback(obj,stone,133);
  fdui->p[13][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,160,20,20,"");
    fl_set_object_callback(obj,stone,153);
  fdui->p[13][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,180,20,20,"");
    fl_set_object_callback(obj,stone,173);
  fdui->p[13][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,200,20,20,"");
    fl_set_object_callback(obj,stone,193);
  fdui->p[13][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,220,20,20,"");
    fl_set_object_callback(obj,stone,213);
  fdui->p[13][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,240,20,20,"");
    fl_set_object_callback(obj,stone,233);
  fdui->p[13][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,260,20,20,"");
    fl_set_object_callback(obj,stone,253);
  fdui->p[13][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,280,20,20,"");
    fl_set_object_callback(obj,stone,273);
  fdui->p[13][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,300,20,20,"");
    fl_set_object_callback(obj,stone,293);
  fdui->p[13][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,320,20,20,"");
    fl_set_object_callback(obj,stone,313);
  fdui->p[13][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,340,20,20,"");
    fl_set_object_callback(obj,stone,333);
  fdui->p[13][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,360,20,20,"");
    fl_set_object_callback(obj,stone,353);
  fdui->p[13][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,260,380,20,20,"");
    fl_set_object_callback(obj,stone,373);
  fdui->p[14][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,20,20,20,"");
    fl_set_object_callback(obj,stone,14);
  fdui->p[14][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,40,20,20,"");
    fl_set_object_callback(obj,stone,34);
  fdui->p[14][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,60,20,20,"");
    fl_set_object_callback(obj,stone,54);
  fdui->p[14][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,80,20,20,"");
    fl_set_object_callback(obj,stone,74);
  fdui->p[14][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,100,20,20,"");
    fl_set_object_callback(obj,stone,94);
  fdui->p[14][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,120,20,20,"");
    fl_set_object_callback(obj,stone,114);
  fdui->p[14][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,140,20,20,"");
    fl_set_object_callback(obj,stone,134);
  fdui->p[14][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,160,20,20,"");
    fl_set_object_callback(obj,stone,154);
  fdui->p[14][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,180,20,20,"");
    fl_set_object_callback(obj,stone,174);
  fdui->p[14][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,200,20,20,"");
    fl_set_object_callback(obj,stone,194);
  fdui->p[14][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,220,20,20,"");
    fl_set_object_callback(obj,stone,214);
  fdui->p[14][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,240,20,20,"");
    fl_set_object_callback(obj,stone,234);
  fdui->p[14][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,260,20,20,"");
    fl_set_object_callback(obj,stone,254);
  fdui->p[14][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,280,20,20,"");
    fl_set_object_callback(obj,stone,274);
  fdui->p[14][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,300,20,20,"");
    fl_set_object_callback(obj,stone,294);
  fdui->p[14][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,320,20,20,"");
    fl_set_object_callback(obj,stone,314);
  fdui->p[14][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,340,20,20,"");
    fl_set_object_callback(obj,stone,334);
  fdui->p[14][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,360,20,20,"");
    fl_set_object_callback(obj,stone,354);
  fdui->p[14][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,280,380,20,20,"");
    fl_set_object_callback(obj,stone,374);
  fdui->p[15][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,20,20,20,"");
    fl_set_object_callback(obj,stone,15);
  fdui->p[15][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,40,20,20,"");
    fl_set_object_callback(obj,stone,35);
  fdui->p[15][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,60,20,20,"");
    fl_set_object_callback(obj,stone,55);
  fdui->p[15][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,80,20,20,"");
    fl_set_object_callback(obj,stone,75);
  fdui->p[15][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,100,20,20,"");
    fl_set_object_callback(obj,stone,95);
  fdui->p[15][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,120,20,20,"");
    fl_set_object_callback(obj,stone,115);
  fdui->p[15][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,140,20,20,"");
    fl_set_object_callback(obj,stone,135);
  fdui->p[15][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,160,20,20,"");
    fl_set_object_callback(obj,stone,155);
  fdui->p[15][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,180,20,20,"");
    fl_set_object_callback(obj,stone,175);
  fdui->p[15][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,200,20,20,"");
    fl_set_object_callback(obj,stone,195);
  fdui->p[15][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,220,20,20,"");
    fl_set_object_callback(obj,stone,215);
  fdui->p[15][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,240,20,20,"");
    fl_set_object_callback(obj,stone,235);
  fdui->p[15][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,260,20,20,"");
    fl_set_object_callback(obj,stone,255);
  fdui->p[15][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,280,20,20,"");
    fl_set_object_callback(obj,stone,275);
  fdui->p[15][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,300,20,20,"");
    fl_set_object_callback(obj,stone,295);
  fdui->p[15][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,320,20,20,"");
    fl_set_object_callback(obj,stone,315);
  fdui->p[15][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,340,20,20,"");
    fl_set_object_callback(obj,stone,335);
  fdui->p[15][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,360,20,20,"");
    fl_set_object_callback(obj,stone,355);
  fdui->p[15][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,300,380,20,20,"");
    fl_set_object_callback(obj,stone,375);
  fdui->p[16][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,20,20,20,"");
    fl_set_object_callback(obj,stone,16);
  fdui->p[16][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,40,20,20,"");
    fl_set_object_callback(obj,stone,36);
  fdui->p[16][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,60,20,20,"");
    fl_set_object_callback(obj,stone,56);
  fdui->p[16][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,80,20,20,"");
    fl_set_object_callback(obj,stone,76);
  fdui->p[16][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,100,20,20,"");
    fl_set_object_callback(obj,stone,96);
  fdui->p[16][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,120,20,20,"");
    fl_set_object_callback(obj,stone,116);
  fdui->p[16][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,140,20,20,"");
    fl_set_object_callback(obj,stone,136);
  fdui->p[16][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,160,20,20,"");
    fl_set_object_callback(obj,stone,156);
  fdui->p[16][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,180,20,20,"");
    fl_set_object_callback(obj,stone,176);
  fdui->p[16][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,200,20,20,"");
    fl_set_object_callback(obj,stone,196);
  fdui->p[16][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,220,20,20,"");
    fl_set_object_callback(obj,stone,216);
  fdui->p[16][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,240,20,20,"");
    fl_set_object_callback(obj,stone,236);
  fdui->p[16][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,260,20,20,"");
    fl_set_object_callback(obj,stone,256);
  fdui->p[16][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,280,20,20,"");
    fl_set_object_callback(obj,stone,276);
  fdui->p[16][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,300,20,20,"");
    fl_set_object_callback(obj,stone,296);
  fdui->p[16][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,320,20,20,"");
    fl_set_object_callback(obj,stone,316);
  fdui->p[16][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,340,20,20,"");
    fl_set_object_callback(obj,stone,336);
  fdui->p[16][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,360,20,20,"");
    fl_set_object_callback(obj,stone,356);
  fdui->p[16][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,320,380,20,20,"");
    fl_set_object_callback(obj,stone,376);
  fdui->p[17][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,20,20,20,"");
    fl_set_object_callback(obj,stone,17);
  fdui->p[17][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,40,20,20,"");
    fl_set_object_callback(obj,stone,37);
  fdui->p[17][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,60,20,20,"");
    fl_set_object_callback(obj,stone,57);
  fdui->p[17][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,80,20,20,"");
    fl_set_object_callback(obj,stone,77);
  fdui->p[17][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,100,20,20,"");
    fl_set_object_callback(obj,stone,97);
  fdui->p[17][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,120,20,20,"");
    fl_set_object_callback(obj,stone,117);
  fdui->p[17][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,140,20,20,"");
    fl_set_object_callback(obj,stone,137);
  fdui->p[17][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,160,20,20,"");
    fl_set_object_callback(obj,stone,157);
  fdui->p[17][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,180,20,20,"");
    fl_set_object_callback(obj,stone,177);
  fdui->p[17][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,200,20,20,"");
    fl_set_object_callback(obj,stone,197);
  fdui->p[17][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,220,20,20,"");
    fl_set_object_callback(obj,stone,217);
  fdui->p[17][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,240,20,20,"");
    fl_set_object_callback(obj,stone,237);
  fdui->p[17][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,260,20,20,"");
    fl_set_object_callback(obj,stone,257);
  fdui->p[17][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,280,20,20,"");
    fl_set_object_callback(obj,stone,277);
  fdui->p[17][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,300,20,20,"");
    fl_set_object_callback(obj,stone,297);
  fdui->p[17][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,320,20,20,"");
    fl_set_object_callback(obj,stone,317);
  fdui->p[17][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,340,20,20,"");
    fl_set_object_callback(obj,stone,337);
  fdui->p[17][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,360,20,20,"");
    fl_set_object_callback(obj,stone,357);
  fdui->p[17][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,340,380,20,20,"");
    fl_set_object_callback(obj,stone,377);
  fdui->p[18][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,20,20,20,"");
    fl_set_object_callback(obj,stone,18);
  fdui->p[18][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,40,20,20,"");
    fl_set_object_callback(obj,stone,38);
  fdui->p[18][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,60,20,20,"");
    fl_set_object_callback(obj,stone,58);
  fdui->p[18][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,80,20,20,"");
    fl_set_object_callback(obj,stone,78);
  fdui->p[18][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,100,20,20,"");
    fl_set_object_callback(obj,stone,98);
  fdui->p[18][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,120,20,20,"");
    fl_set_object_callback(obj,stone,118);
  fdui->p[18][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,140,20,20,"");
    fl_set_object_callback(obj,stone,138);
  fdui->p[18][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,160,20,20,"");
    fl_set_object_callback(obj,stone,158);
  fdui->p[18][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,180,20,20,"");
    fl_set_object_callback(obj,stone,178);
  fdui->p[18][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,200,20,20,"");
    fl_set_object_callback(obj,stone,198);
  fdui->p[18][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,220,20,20,"");
    fl_set_object_callback(obj,stone,218);
  fdui->p[18][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,240,20,20,"");
    fl_set_object_callback(obj,stone,238);
  fdui->p[18][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,260,20,20,"");
    fl_set_object_callback(obj,stone,258);
  fdui->p[18][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,280,20,20,"");
    fl_set_object_callback(obj,stone,278);
  fdui->p[18][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,300,20,20,"");
    fl_set_object_callback(obj,stone,298);
  fdui->p[18][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,320,20,20,"");
    fl_set_object_callback(obj,stone,318);
  fdui->p[18][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,340,20,20,"");
    fl_set_object_callback(obj,stone,338);
  fdui->p[18][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,360,20,20,"");
    fl_set_object_callback(obj,stone,358);
  fdui->p[18][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,360,380,20,20,"");
    fl_set_object_callback(obj,stone,378);
  fdui->p[19][1] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,20,20,20,"");
    fl_set_object_callback(obj,stone,19);
  fdui->p[19][2] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,40,20,20,"");
    fl_set_object_callback(obj,stone,39);
  fdui->p[19][3] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,60,20,20,"");
    fl_set_object_callback(obj,stone,59);
  fdui->p[19][4] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,80,20,20,"");
    fl_set_object_callback(obj,stone,79);
  fdui->p[19][5] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,100,20,20,"");
    fl_set_object_callback(obj,stone,99);
  fdui->p[19][6] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,120,20,20,"");
    fl_set_object_callback(obj,stone,119);
  fdui->p[19][7] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,140,20,20,"");
    fl_set_object_callback(obj,stone,139);
  fdui->p[19][8] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,160,20,20,"");
    fl_set_object_callback(obj,stone,159);
  fdui->p[19][9] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,180,20,20,"");
    fl_set_object_callback(obj,stone,179);
  fdui->p[19][10] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,200,20,20,"");
    fl_set_object_callback(obj,stone,199);
  fdui->p[19][11] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,220,20,20,"");
    fl_set_object_callback(obj,stone,219);
  fdui->p[19][12] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,240,20,20,"");
    fl_set_object_callback(obj,stone,239);
  fdui->p[19][13] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,260,20,20,"");
    fl_set_object_callback(obj,stone,259);
  fdui->p[19][14] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,280,20,20,"");
    fl_set_object_callback(obj,stone,279);
  fdui->p[19][15] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,300,20,20,"");
    fl_set_object_callback(obj,stone,299);
  fdui->p[19][16] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,320,20,20,"");
    fl_set_object_callback(obj,stone,319);
  fdui->p[19][17] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,340,20,20,"");
    fl_set_object_callback(obj,stone,339);
  fdui->p[19][18] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,360,20,20,"");
    fl_set_object_callback(obj,stone,359);
  fdui->p[19][19] = obj = fl_add_button(FL_HIDDEN_BUTTON,380,380,20,20,"");
    fl_set_object_callback(obj,stone,379);
  fdui->bc = obj = fl_add_button(FL_NORMAL_BUTTON,420,385,60,20,"Cancel");
    fl_set_object_callback(obj,close_dia,0);
  fdui->bs = obj = fl_add_button(FL_NORMAL_BUTTON,420,360,60,20,"Save");
    fl_set_object_callback(obj,save_dia,0);
  fdui->cn = obj = fl_add_counter(FL_SIMPLE_COUNTER,420,90,60,20,"");
    fl_set_counter_precision(obj, 0);
    fl_set_counter_bounds(obj, 1, 361);
    fl_set_counter_value(obj, 1);
    fl_set_counter_step(obj, 1, 1);
  fdui->bcl = obj = fl_add_button(FL_NORMAL_BUTTON,420,335,60,20,"Clear");
    fl_set_object_callback(obj,clear_dia,0);
  fdui->bt = obj = fl_add_button(FL_NORMAL_BUTTON,420,295,60,20,"Caption");
    fl_set_object_callback(obj,get_caption,0);

  fdui->color = fl_bgn_group();
  fdui->fc = obj = fl_add_labelframe(FL_ENGRAVED_FRAME,420,15,60,60,"Color");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
  fdui->bb = obj = fl_add_roundbutton(FL_RADIO_BUTTON,420,30,60,20,"Black");
    fl_set_object_color(obj,FL_COL1,FL_BOTTOM_BCOL);
    fl_set_object_callback(obj,increase_no,1);
  fdui->bw = obj = fl_add_roundbutton(FL_RADIO_BUTTON,420,50,60,20,"White");
    fl_set_object_color(obj,FL_COL1,FL_WHITE);
    fl_set_object_callback(obj,increase_no,2);
  fl_end_group();


  fdui->mark = fl_bgn_group();
  fdui->fm = obj = fl_add_labelframe(FL_ENGRAVED_FRAME,420,205,60,80,"Marks");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
  fdui->mb[1] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,430,215,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
    fl_set_object_lstyle(obj,15);
  fdui->mb[2] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,450,215,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->mb[3] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,430,235,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->mb[4] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,450,235,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->mb[5] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,430,255,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->mb[6] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,450,255,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
    fl_set_object_callback(obj,open_marks,0);
  fl_end_group();

  fdui->bnr = obj = fl_add_lightbutton(FL_PUSH_BUTTON,420,115,60,20,"  No.");
    fl_set_object_color(obj,FL_COL1,FL_CHARTREUSE);
  fdui->ber = obj = fl_add_lightbutton(FL_PUSH_BUTTON,420,145,60,20,"Erase");
  fdui->bu = obj = fl_add_lightbutton(FL_PUSH_BUTTON,420,175,60,20,"Mark");
    fl_set_object_color(obj,FL_COL1,FL_DARKORANGE);
  fl_end_form();

  fdui->dia->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

FD_info *create_form_info(void)
{
  FL_OBJECT *obj;
  FD_info *fdui = (FD_info *) fl_calloc(1, sizeof(*fdui));

  fdui->info = fl_bgn_form(FL_NO_BOX, 470, 390);
  obj = fl_add_box(FL_UP_BOX,0,0,470,390,"");
  fdui->br1 = obj = fl_add_browser(FL_NORMAL_BROWSER,20,20,430,300,"");
    fl_set_object_lsize(obj,FL_NORMAL_SIZE);
  fdui->be = obj = fl_add_button(FL_NORMAL_BUTTON,370,340,80,30,"Exit");
    fl_set_object_callback(obj,close_info,0);

  fdui->inf = fl_bgn_group();
  fdui->bx = obj = fl_add_lightbutton(FL_RADIO_BUTTON,20,340,60,30," Xgod");
    fl_set_object_callback(obj,show_text,1);
  fdui->bg = obj = fl_add_lightbutton(FL_RADIO_BUTTON,90,340,70,30," Ntf-go");
    fl_set_object_color(obj,FL_COL1,FL_TOMATO);
    fl_set_object_callback(obj,show_text,2);
  fdui->bc = obj = fl_add_lightbutton(FL_RADIO_BUTTON,170,340,80,30,"Copyright");
    fl_set_object_color(obj,FL_COL1,FL_CHARTREUSE);
    fl_set_object_callback(obj,show_text,0);
  fdui->bl = obj = fl_add_lightbutton(FL_RADIO_BUTTON,260,340,90,30,"Gnu License");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
    fl_set_object_callback(obj,show_text,0);
  fl_end_group();

  fl_end_form();

  fdui->info->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

FD_marks *create_form_marks(void)
{
  FL_OBJECT *obj;
  FD_marks *fdui = (FD_marks *) fl_calloc(1, sizeof(*fdui));

  fdui->marks = fl_bgn_form(FL_NO_BOX, 300, 90);
  obj = fl_add_box(FL_UP_BOX,0,0,300,90,"");

  fdui->mk = fl_bgn_group();
  fdui->b[1] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,20,20,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[2] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,50,20,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[3] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,80,20,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[4] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,110,20,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[5] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,140,20,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[6] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,20,50,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[7] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,50,50,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[8] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,80,50,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[9] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,110,50,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fdui->b[10] = obj = fl_add_bitmapbutton(FL_RADIO_BUTTON,140,50,20,20,"");
    fl_set_object_color(obj,FL_COL1,FL_CYAN);
  fl_end_group();

  fdui->bc = obj = fl_add_button(FL_NORMAL_BUTTON,230,20,50,50,"Close");
    fl_set_object_callback(obj,close_marks,0);
  fdui->bu = obj = fl_add_button(FL_NORMAL_BUTTON,170,20,50,50,"Unmark");
    fl_set_object_callback(obj,unmark,0);
  fl_end_form();

  fdui->marks->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

